VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "CHorizontalSplitter"
Attribute VB_Creatable = False
Attribute VB_Exposed = False
Option Explicit

' API declarations
#If Win32 Then
   Private Declare Function SetCapture Lib "User32" (ByVal hWnd As Long) As Long
   Private Declare Function ReleaseCapture Lib "User32" () As Long
#Else
   Private Declare Function SetCapture Lib "User" (ByVal hWnd As Integer) As Integer
   Private Declare Function ReleaseCapture Lib "User" () As Integer
#End If

' sizing constants
Const THREED_PAD = 30

' color constants
Const DARKGRAY = &H808080
Const LIGHTGRAY = &HC0C0C0

' stored public properties
Private mpicBar As PictureBox
Private mvContainer As Variant
Private mvTopChild As Variant
Private mvBottomChild As Variant

' private properties
Private mnBarHeight As Integer
Private mbMouseDown As Boolean

'''''''''''''''''''''
' public properties '
'''''''''''''''''''''
Public Property Get BarHeight() As Integer

   ' return bar height
   BarHeight = mpicBar.Height
   
End Property

Public Property Let BarHeight(ByVal vnBarHeight As Integer)

   ' let bar height if not negative
   If vnBarHeight > 0 Then
      mpicBar.Height = vnBarHeight
      mnBarHeight = vnBarHeight
      
      ' adjust the children
      RefreshHeight
   End If
   
End Property
Public Property Get BottomChild() As Variant

   ' return bottom child
   Set BottomChild = mvBottomChild
   
End Property

Public Property Set BottomChild(Child As Variant)

   ' set bottom child
   Set mvBottomChild = Child
   
End Property

Public Property Get Height() As Integer
   
   ' return height
   Height = mvContainer.Height
   
End Property

Public Property Let Height(ByVal vnHeight As Integer)
   
   ' let height if not negative
   If vnHeight >= 0 Then
      mvContainer.Height = vnHeight
   
      ' adjust the children
      RefreshHeight
   End If
   
End Property

Public Property Get Left() As Integer
   
   ' return left
   Left = mvContainer.Left
   
End Property

Public Property Let Left(ByVal vnLeft As Integer)
   
   ' let left if not negative
   If vnLeft >= 0 Then
      mvContainer.Left = vnLeft
   End If
   
End Property

Public Property Get Top() As Integer
   
   ' return top
   Top = mvContainer.Top
   
End Property

Public Property Let Top(ByVal vnTop As Integer)
   
   ' let top if not negative
   If vnTop >= 0 Then
      mvContainer.Top = vnTop
   End If
   
End Property

Public Property Get Visible() As Boolean

   ' return visible
   Visible = mvContainer.Visible
   
End Property

Public Property Let Visible(ByVal vbVisible As Boolean)

   ' set visible
   mvContainer.Visible = vbVisible
   
End Property

Public Property Get TopChild() As Variant

   ' return top child
   Set TopChild = mvTopChild
   
End Property

Public Property Set TopChild(Child As Variant)

   ' set top child
   Set mvTopChild = Child
   
End Property

Public Property Get Width() As Integer
   
   ' return width
   Width = mvContainer.Width
   
End Property

Public Property Let Width(ByVal vnWidth As Integer)
   
   ' let width if not negative
   If vnWidth >= 0 Then
      mvContainer.Width = vnWidth

      ' adjust the bar and the children
      RefreshWidth
   End If
   
End Property

''''''''''''''''''
' public methods '
''''''''''''''''''
Public Sub Init(Container As Variant, _
   Bar As PictureBox, _
   TopChild As Variant, _
   BottomChild As Variant)

   ' do this once
   Static sbBeenHere As Boolean
   If Not sbBeenHere Then
      sbBeenHere = True
   
      ' store the parameters
      Set mvContainer = Container
      Set mpicBar = Bar
      Set mvTopChild = TopChild
      If Not mvTopChild Is Nothing Then _
         Set mvTopChild.Container = mvContainer
      Set mvBottomChild = BottomChild
      If Not mvBottomChild Is Nothing Then _
         Set mvBottomChild.Container = mvContainer
      mnBarHeight = mpicBar.Height
      
      ' make sure that the splitter is on top
      mpicBar.ZOrder vbBringToFront
      
      ' refresh all
      Me.Refresh
   End If
   
End Sub

Public Sub MouseDown()

   ' record the new state
   mbMouseDown = True
   
   ' capture the mouse
   SetCapture mpicBar.hWnd

   ' adjust the bar's appearance
   mpicBar.BackColor = DARKGRAY
   mpicBar.Height = mnBarHeight + 15
   mpicBar.ZOrder vbBringToFront
   
End Sub

Public Sub MouseMove(ByVal Y As Single)
   
   ' move the bar if the mouse button is down
   If mbMouseDown Then _
      mpicBar.Top = mpicBar.Top + Y

End Sub

Public Sub MouseUp()
   
   ' record the new state
   mbMouseDown = False

   ' release the mouse capture
   ReleaseCapture
   
   ' reset the bar's appearance
   mpicBar.Height = mnBarHeight
   mpicBar.BackColor = LIGHTGRAY
   
   ' make sure that the bar was not moved to far
   Dim nMax As Integer
   nMax = mvContainer.ScaleHeight - THREED_PAD
   Dim nMin As Integer
   nMin = 0
   If mpicBar.Top < nMin Then
      mpicBar.Top = nMin
   ElseIf mpicBar.Top > nMax Then
      mpicBar.Top = nMax
   End If
   
   ' adjust the children
   RefreshHeight
   
End Sub

Public Sub Move(ByVal Left As Integer, _
   Optional ByVal Top As Variant, _
   Optional ByVal Width As Variant, _
   Optional ByVal Height As Variant)
   
   ' move the container
   Me.Left = Left
   If Not VarType(Top) = vbError Then _
      Me.Top = Top
   If Not VarType(Width) = vbError Then
      Me.Width = Width
   End If
   If Not VarType(Height) = vbError Then
      Me.Height = Height
   End If
   
End Sub

Public Sub Refresh()

   ' refresh all
   RefreshHeight
   RefreshWidth
   
End Sub

'''''''''''''''''''
' private methods '
'''''''''''''''''''
Private Sub RefreshHeight()

   ' position and size the children (height only);
   ' handle the top child
   If Not mvTopChild Is Nothing Then
   
      ' position the top child
      mvTopChild.Top = 0
      
      ' adjust the height of the top child
      If mpicBar.Top > 0 Then
         mvTopChild.Height = mpicBar.Top
         mvTopChild.Visible = True
      Else
         mvTopChild.Visible = False
      End If
   End If
   
   ' handle the bottom child
   If Not mvBottomChild Is Nothing Then
   
      ' position the bottom child
      mvBottomChild.Top = _
         mpicBar.Top + mpicBar.Height
      
      ' adjust the height of the bottom child
      Dim nBottomHeight As Integer
      nBottomHeight = mvContainer.ScaleHeight - _
         mpicBar.Top - mpicBar.Height - THREED_PAD
      If nBottomHeight > 0 Then
         mvBottomChild.Height = nBottomHeight
         mvBottomChild.Visible = True
      Else
         mvBottomChild.Visible = False
      End If
   End If
   
End Sub

Private Sub RefreshWidth()

   ' adjust the width of the bar
   ' and the children
   mpicBar.Left = 0
   mpicBar.Width = _
      mvContainer.ScaleWidth
   If Not mvTopChild Is Nothing Then
      mvTopChild.Left = 0
      mvTopChild.Width = _
         mvContainer.ScaleWidth
   End If
   If Not mvBottomChild Is Nothing Then
      mvBottomChild.Left = 0
      mvBottomChild.Width = _
         mvContainer.ScaleWidth
   End If
   
End Sub
