VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "CVerticalSplitter"
Attribute VB_Creatable = False
Attribute VB_Exposed = False
Option Explicit

' API declarations
#If Win32 Then
   Private Declare Function SetCapture Lib "User32" (ByVal hWnd As Long) As Long
   Private Declare Function ReleaseCapture Lib "User32" () As Long
#Else
   Private Declare Function SetCapture Lib "User" (ByVal hWnd As Integer) As Integer
   Private Declare Function ReleaseCapture Lib "User" () As Integer
#End If

' sizing constants
Const THREED_PAD = 0

' color constants
Const DARKGRAY = &H808080
Const LIGHTGRAY = &HC0C0C0

' stored public properties
Private mpicBar As PictureBox
Private mvContainer As Variant
Private mvLeftChild As Variant
Private mvRightChild As Variant

' private properties
Private mnBarWidth As Integer
Private mbMouseDown As Boolean

'''''''''''''''''''''
' public properties '
'''''''''''''''''''''
Public Property Get BarWidth() As Integer

   ' return bar width
   BarWidth = mpicBar.Width
   
End Property

Public Property Let BarWidth(ByVal vnBarWidth As Integer)

   ' let bar width if not negative
   If vnBarWidth > 0 Then
      mpicBar.Width = vnBarWidth
      mnBarWidth = vnBarWidth
      
      ' adjust the children
      RefreshWidth
   End If
   
End Property

Public Property Get Height() As Integer
   
   ' return height
   Height = mvContainer.Height
   
End Property

Public Property Let Height(ByVal vnHeight As Integer)
   
   ' let height if not negative
   If vnHeight >= 0 Then
      mvContainer.Height = vnHeight
   
      ' adjust the bar and the children
      RefreshHeight
   End If
   
End Property

Public Property Get Left() As Integer
   
   ' return left
   Left = mvContainer.Left
   
End Property

Public Property Let Left(ByVal vnLeft As Integer)
   
   ' let left if not negative
   If vnLeft >= 0 Then
      mvContainer.Left = vnLeft
   End If
   
End Property

Public Property Get LeftChild() As Variant

   ' return top child
   Set LeftChild = mvLeftChild
   
End Property

Public Property Set LeftChild(Child As Variant)

   ' set top child
   Set mvLeftChild = Child
   If Not mvLeftChild Is Nothing Then _
      Set mvLeftChild.Container = mvContainer
   Me.Refresh
   
End Property

Public Property Get RightChild() As Variant

   ' return bottom child
   Set RightChild = mvRightChild
   
End Property

Public Property Set RightChild(Child As Variant)

   ' set bottom child
   Set mvRightChild = Child
   If Not mvRightChild Is Nothing Then _
      Set mvRightChild.Container = mvContainer
   Me.Refresh
   
End Property

Public Property Get Top() As Integer
   
   ' return top
   Top = mvContainer.Top
   
End Property

Public Property Let Top(ByVal vnTop As Integer)
   
   ' let top if not negative
   If vnTop >= 0 Then
      mvContainer.Top = vnTop
   End If
   
End Property

Public Property Get Visible() As Boolean

   ' return visible
   Visible = mvContainer.Visible
   
End Property

Public Property Let Visible(ByVal vbVisible As Boolean)

   ' set visible
   mvContainer.Visible = vbVisible
   
End Property

Public Property Get Width() As Integer
   
   ' return width
   Width = mvContainer.Width
   
End Property

Public Property Let Width(ByVal vnWidth As Integer)
   
   ' let width if not negative
   If vnWidth >= 0 Then
      mvContainer.Width = vnWidth

      ' adjust the children
      RefreshWidth
   End If
   
End Property

''''''''''''''''''
' public methods '
''''''''''''''''''
Public Sub Init(Container As Variant, _
   Bar As PictureBox, _
   LeftChild As Variant, _
   RightChild As Variant)

   ' do this once
   Static sbBeenHere As Boolean
   If Not sbBeenHere Then
      sbBeenHere = True
   
      ' store the parameters
      Set mvContainer = Container
      Set mpicBar = Bar
      Set mvLeftChild = LeftChild
      If Not mvLeftChild Is Nothing Then _
         Set mvLeftChild.Container = mvContainer
      Set mvRightChild = RightChild
      If Not mvRightChild Is Nothing Then _
         Set mvRightChild.Container = mvContainer
      mnBarWidth = mpicBar.Width
      
      ' make sure that the splitter is on top
      mpicBar.ZOrder vbBringToFront
      
      ' refresh all
      Me.Refresh
   End If
   
End Sub

Public Sub MouseDown()

   ' record the new state
   mbMouseDown = True
   
   ' capture the mouse
   SetCapture mpicBar.hWnd

   ' adjust the bar's appearance
   mpicBar.BackColor = DARKGRAY
   mpicBar.Width = mnBarWidth + 15
   mpicBar.ZOrder vbBringToFront
   
End Sub

Public Sub MouseMove(ByVal X As Single)
   
   ' move the splitter if the mouse button is down
   If mbMouseDown Then _
      mpicBar.Left = mpicBar.Left + X

End Sub

Public Sub MouseUp()
   
   ' record the new state
   mbMouseDown = False

   ' release the mouse capture
   ReleaseCapture
   
   ' reset the bar's appearance
   mpicBar.Width = mnBarWidth
   mpicBar.BackColor = LIGHTGRAY
   
   ' make sure that the bar was not moved to far
   Dim nMax As Integer
   nMax = mvContainer.ScaleWidth - THREED_PAD
   Dim nMin As Integer
   nMin = 0
   If mpicBar.Left < nMin Then
      mpicBar.Left = nMin
   ElseIf mpicBar.Left > nMax Then
      mpicBar.Left = nMax
   End If
   
   ' adjust the children
   RefreshWidth
   
End Sub

Public Sub Move(ByVal Left As Integer, _
   Optional ByVal Top As Variant, _
   Optional ByVal Width As Variant, _
   Optional ByVal Height As Variant)
   
   ' move the splitter
   Me.Left = Left
   If Not VarType(Top) = vbError Then _
      Me.Top = Top
   If Not VarType(Width) = vbError Then
      Me.Width = Width
   End If
   If Not VarType(Height) = vbError Then
      Me.Height = Height
   End If
   
End Sub

Public Sub Refresh()

   ' refresh all
   RefreshHeight
   RefreshWidth
   
End Sub

Private Sub RefreshHeight()

   ' adjust the height of the bar
   ' and the children
   mpicBar.Top = 0
   mpicBar.Height = _
      mvContainer.ScaleHeight
   If Not mvLeftChild Is Nothing Then
      mvLeftChild.Top = 0
      mvLeftChild.Height = _
         mvContainer.ScaleHeight
   End If
   If Not mvRightChild Is Nothing Then
      mvRightChild.Top = 0
      mvRightChild.Height = _
         mvContainer.ScaleHeight
   End If

End Sub

Private Sub RefreshWidth()

   ' position and size the children (width only);
   ' handle the right child
   If Not mvLeftChild Is Nothing Then
   
      ' position the left child
      mvLeftChild.Move 0, 0
      
      ' adjust the width of the left child
      If mpicBar.Left > 0 Then
         mvLeftChild.Width = mpicBar.Left
         mvLeftChild.Visible = True
      Else
         mvLeftChild.Visible = False
      End If
   End If
   
   ' handle the right child
   If Not mvRightChild Is Nothing Then
   
      ' position the right child
      mvRightChild.Move _
         mpicBar.Left + mpicBar.Width, 0
      
      ' adjust the width of the right child
      Dim nRightWidth As Integer
      nRightWidth = mvContainer.ScaleWidth - _
         mpicBar.Left - mpicBar.Width - THREED_PAD
      If nRightWidth > 0 Then
         mvRightChild.Width = nRightWidth
         mvRightChild.Visible = True
      Else
         mvRightChild.Visible = False
      End If
   End If
   
End Sub
